@@ -35,6 +35,8 @@
 #include <gst/gst.h>
 #include <locale.h>
 
+#include <gdk/gdkkeysyms.h>
+
 #include <gconf/gconf-client.h>
 
 #ifdef MAEMO_CHANGES /* probably not the best macro to check for here */
@@ -49,6 +51,7 @@
 #ifndef LEGACY
 #    include <hildon/hildon-program.h>
 #    include <hildon/hildon-banner.h>
+#    include <hildon/hildon-note.h>
 #else
 #    include <hildon-widgets/hildon-program.h>
 #    include <hildon-widgets/hildon-banner.h>
@@ -320,6 +323,234 @@ maemo_mapper_destroy()
     g_thread_pool_free(_mut_thread_pool, TRUE, TRUE);
 }
 
+static void
+move(MapController *controller, MapPoint *point,
+     gint angle, gint distance)
+{
+    gint new_angle;
+
+    new_angle = map_controller_get_rotation(controller) + angle;
+    (*point).x += distance * GCOS(deg2rad(new_angle));
+    (*point).y += distance * GSIN(deg2rad(new_angle));
+}
+
+static gboolean
+key_press (GtkWidget *widget,
+           GdkEventKey *event,
+           MapController *controller)
+{
+    MapPoint center;
+    GtkWidget *note;
+    switch (event->keyval) {
+    case ' ': /* fullscreen */
+        map_controller_action_switch_fullscreen(controller);
+        break;
+
+    /* s,f have +,- signs on them */
+    case 'f':
+        map_controller_action_zoom_out(controller);
+        break;
+    case 's':
+        map_controller_action_zoom_in(controller);
+        break;
+
+    case GDK_Left:
+        map_controller_get_center(controller, &center);
+        move(controller, &center, 180,
+             50 << map_controller_get_zoom(controller));
+        map_controller_set_center(controller, center, -1);
+        break;
+    case GDK_Right:
+        map_controller_get_center(controller, &center);
+        move(controller, &center, 0,
+             50 << map_controller_get_zoom(controller));
+        map_controller_set_center(controller, center, -1);
+        break;
+    case GDK_Down:
+        map_controller_get_center(controller, &center);
+        move(controller, &center, 90,
+             50 << map_controller_get_zoom(controller));
+        map_controller_set_center(controller, center, -1);
+        break;
+    case GDK_Up:
+        map_controller_get_center(controller, &center);
+        move(controller, &center, 270,
+             50 << map_controller_get_zoom(controller));
+        map_controller_set_center(controller, center, -1);
+        break;
+
+    case 'G':
+        map_controller_set_gps_enabled(controller,
+            !map_controller_get_gps_enabled(controller));
+        break;
+
+    case 'g':
+        map_controller_set_show_gps_info(controller,
+            !map_controller_get_show_gps_info(controller));
+        break;
+    case 'v':
+        map_controller_set_show_velocity(controller,
+            !map_controller_get_show_velocity(controller));
+        break;
+    case 'z':
+        map_controller_set_show_zoom(controller,
+            !map_controller_get_show_zoom(controller));
+        break;
+    case 'p':
+        map_controller_set_show_poi(controller,
+            !map_controller_get_show_poi(controller));
+        break;
+    case 'l':
+        map_controller_set_show_scale(controller,
+            !map_controller_get_show_scale(controller));
+        break;
+    case 't':
+        map_controller_set_show_tracks(controller,
+            !map_controller_get_show_tracks(controller));
+        break;
+    case 'c':
+        map_controller_set_show_compass(controller,
+            !map_controller_get_show_compass(controller));
+        break;
+    case 'r':
+        map_controller_set_show_routes(controller,
+            !map_controller_get_show_routes(controller));
+        break;
+
+    case 'x':
+        map_controller_set_center_mode(controller,
+            !map_controller_get_center_mode(controller));
+        break;
+    case 'a':
+        map_controller_set_auto_rotate(controller,
+            !map_controller_get_auto_rotate(controller));
+        break;
+
+    /* menus */
+    case 'o':
+        map_controller_action_go_to(controller);
+        break;
+    case 'm':
+        map_controller_action_route(controller);
+        break;
+    case 'n':
+        map_controller_action_track(controller);
+        break;
+    case 'b':
+        map_controller_action_view(controller);
+        break;
+    case 'i':
+        map_controller_action_point(controller);
+        break;
+    case 'u':
+        map_controller_get_center(controller, &center);
+        map_controller_activate_menu_point(controller, &center);
+        break;
+
+    /* menu items */
+    case 'P':
+        map_controller_disable_auto_center(controller);
+        map_controller_set_center(controller, _pos.unit, -1);
+        break;
+    case 'W':
+        menu_cb_view_goto_nextway(NULL);
+        break;
+    case 'F':
+        menu_cb_view_goto_address(NULL);
+        break;
+    case 'T':
+        map_controller_set_tracking(controller,
+                                    !map_controller_get_tracking(controller));
+        break;
+    case 'Y':
+        menu_cb_track_clear(NULL);
+        break;
+    case 'U':
+        menu_cb_track_insert_break(NULL);
+        break;
+    case 'I':
+        menu_cb_track_save(NULL);
+        break;
+    case 'O':
+        map_controller_get_center(controller, &center);
+        map_controller_set_gps_position(controller, &center);
+        break;
+    case 'R':
+        menu_cb_route_download(NULL);
+        break;
+
+    case 'h':
+    case '?':
+        note = hildon_note_new_information(GTK_WINDOW(_window),
+            "OSD toggles\n"
+            "z-zoom\t\t"
+            "b-View menu\t"
+            "f-zoom out\n"
+
+            "c-compass\t"
+            "i-Point menu\t\t"
+            "s-zoom in\n"
+
+            "g-GPS info\t"
+            "m-Route menu\t"
+            "h-help\n"
+
+            "l-scale\t\t"
+            "n-Track menu\t"
+            "G-GPS on/off\n"
+
+            "p-POI\t\t"
+            "o-Goto menu\t\t"
+            "W-next waypoint\n"
+
+            "r-routes\t\t"
+            "P-goto GPS pos\t"
+            "u-Point action\n"
+
+            "t-tracks\t\t"
+            "a-toggle autorotate\n"
+            "v-velocity\t"
+            "x-toggle autocenter\n"
+
+            "\t\t\t"
+            "F-Find address\t"
+            "T-toggle tracking\n"
+
+            "Y-clear track\t"
+            "U-break track\t"
+            "I-save track\n"
+
+            "\t\t\t"
+            "R-set destination\t"
+            "O-Set as GPS pos\n"
+
+            "\t\t\t"
+            "\t\t\t"
+            "\n"
+            );
+        gtk_dialog_run(GTK_DIALOG(note));
+        gtk_widget_destroy(note);
+        break;
+    }
+    return FALSE;
+}
+
+static gboolean
+key_release (GtkWidget *widget,
+             GdkEventKey *event,
+             MapController *controller)
+{
+    switch (event->keyval) {
+    /* s,f have +,- signs on them */
+    case 'f':
+    case 's':
+        map_controller_action_zoom_stop(controller);
+        break;
+    }
+    return FALSE;
+}
+
+
 /**
  * Initialize everything required in preparation for calling gtk_main().
  */
@@ -397,6 +628,15 @@ maemo_mapper_init(gint argc, gchar **argv)
     g_signal_connect(G_OBJECT(_window), "destroy",
             G_CALLBACK(gtk_main_quit), NULL);
 
+    /* keyboard events */
+    gtk_widget_add_events (_window, GDK_KEY_PRESS_MASK);
+    g_signal_connect (G_OBJECT(_window), "key-release-event",
+                      G_CALLBACK (key_release),
+                      _controller);
+    g_signal_connect (G_OBJECT(_window), "key-press-event",
+                      G_CALLBACK (key_press),
+                      _controller);
+
     gtk_widget_show(_window);
     menu_init();
     path_init();
